@@ -5,13 +5,11 @@ Command Line tool for the PeakRDL Python
 #!/usr/bin/env python3
 import argparse
 import os
-import subprocess
 import unittest.loader
+import warnings
 from typing import List, Optional
 import pathlib
 
-import coverage # type: ignore
-
 from systemrdl import RDLCompiler # type: ignore
 from systemrdl.node import Node, AddrmapNode # type: ignore
 from peakrdl_ipxact import IPXACTImporter # type: ignore
@@ -41,8 +39,6 @@ def build_command_line_parser() -> argparse.ArgumentParser:
                              'global addrmap)')
     parser.add_argument('--verbose', '-v', action='count', default=0,
                         help='set logging verbosity')
-    parser.add_argument('--autoformat', action='store_true',
-                        help='use autopep8 on generated code')
     parser.add_argument('--async', action='store_true',
                         help='builds the register model using the async callbacks')
     parser.add_argument('--ipxact', dest='ipxact', nargs='*',
@@ -50,14 +46,8 @@ def build_command_line_parser() -> argparse.ArgumentParser:
     parser.add_argument('--user_template_dir', action='store', type=pathlib.Path,
                            help='directory of user templates to override the default ones')
     checker = parser.add_argument_group('post-generate checks')
-    checker.add_argument('--lint', action='store_true',
-                         help='run pylint on the generated python')
     checker.add_argument('--test', action='store_true',
                          help='run unittests for the created')
-    checker.add_argument('--coverage', action='store_true',
-                         help='run a coverage report on the unittests')
-    checker.add_argument('--html_coverage_out',
-                         help='output director (default: %(default)s)')
     parser.add_argument('--skip_test_case_generation', action='store_true',
                         help='skip the generation of the test cases')
 
@@ -96,7 +86,7 @@ def compile_rdl(infile:str,
 
 
 def generate(root:Node, outdir:str,
-             autoformatoutputs:bool=True,asyncoutput:bool=False,
+             asyncoutput:bool=False,
              skip_test_case_generation:bool=False) -> List[str]:
     """
     Generate a PeakRDL output package from compiled systemRDL
@@ -104,8 +94,6 @@ def generate(root:Node, outdir:str,
     Args:
         root: node in the systemRDL from which the code should be generated
         outdir: directory to store the result in
-        autoformatoutputs: If set to True the code will be run through autopep8 to
-                clean it up. This can slow down large jobs or mask problems
         asyncoutput: If set to True the code build a register model with async operations to
                 access the harware layer
 
@@ -115,28 +103,11 @@ def generate(root:Node, outdir:str,
     """
     print(f'Info: Generating python for {root.inst_name} in {outdir}')
     modules = PythonExporter().export(root, outdir, # type: ignore[no-untyped-call]
-                                      autoformatoutputs=autoformatoutputs,
                                       asyncoutput=asyncoutput,
                                       skip_test_case_generation=skip_test_case_generation)
 
     return modules
 
-def run_lint(root:str, outdir:str) -> None:
-    """
-    Run the lint checks using pylint on a directory
-
-    Args:
-        root: name of the generated package (directory)
-        outdir: location where the package has been written
-
-    Returns:
-
-    """
-    subprocess.run(['pylint', '--rcfile',
-                    os.path.join('tests','pylint.rc'),
-                    os.path.join(outdir, root)],
-                   check=False)
-
 def main_function() -> None:
     """
     Main function for the Command Line tool, this needs to be separated out so that it can be
@@ -162,36 +133,26 @@ def main_function() -> None:
     print('***************************************************************')
     print('* Generate the Python Package                                 *')
     print('***************************************************************')
-    generate(spec, args.outdir, autoformatoutputs=args.autoformat,
+    generate(spec, args.outdir,
              skip_test_case_generation=args.skip_test_case_generation,
              asyncoutput=args.asyncoutput)
 
-    if args.lint:
-        print('***************************************************************')
-        print('* Lint Checks                                                 *')
-        print('***************************************************************')
-        run_lint(outdir=args.outdir, root=spec.inst_name)
     if args.test:
         print('***************************************************************')
         print('* Unit Test Run                                               *')
         print('***************************************************************')
-        if args.coverage:
-            cov = coverage.Coverage(
-                include=[f'*\\{spec.inst_name}\\reg_model\\*.py',
-                         f'*\\{spec.inst_name}\\tests\\*.py'])
-            cov.start()
+
         tests = unittest.TestLoader().discover(
             start_dir=os.path.join(args.outdir, spec.inst_name, 'tests'),
             top_level_dir=args.outdir)
         runner = unittest.TextTestRunner()
         runner.run(tests)
 
-        if args.coverage:
-            cov.stop()
-
-        if args.html_coverage_out is not None:
-            cov.html_report(directory=args.html_coverage_out)
-
-
 if __name__ == '__main__':
+
+    warnings.warn('The peakpython command line option will be removed in a future release. '
+                  'Command line functionality should be used via the see '
+                  'https://peakrdl-python.readthedocs.io/en/latest/command_line.html',
+                  category=PendingDeprecationWarning)
+
     main_function()
